# ﻿B-H Curve

The magnetic field density (H) around a current carrying coil depends on the coil parameters and the current. The magnetic flux density (B) depends on H and the magnetic permeability of the medium. B and H They are related by the equation B=μH where μ is the permeability.

Permeability is not a constant for ferromagnetic materials, like iron. If H is increased B increases and saturated at some point. When we reduce H, B does not follow the same path, as shown in the figure.

# Objective

To Record Magnetic Hysterisis using a solenoid connected to PV1, and a MPU925x magnetometer connected to the I2C port.

# Procedure

- Connect the coil between PV1 and ground
- Connect the Magnetometer(MPU925x) to the I2C port
- Place the solenoid on top of the sensor such that the magnetic axis is perpendicular to the sensor
- Acquire data : This changes the PV1 voltage from -3 to 3 volts in 100 steps, and returns from 3V to -3V . This results in a proportional magnetic field generated by the solenoid which is also measured by the sensor and plotted
- Add a ferromagnetic material such as an alligator clip, and repeat the acquisition. Observe the hysteris for various different materials.